@@ -162,11 +162,15 @@ cmd_string(int cmd)
 			return "SetTheme_SolarLight";
 		case cmd_SetTheme_GruvboxLight:
 			return "SetTheme_GruvboxLight";
+		case cmd_SetTheme_TaoLight:
+			return "SetTheme_TaoLight";
 		case cmd_SaveSetup:
 			return "SaveSetup";
 
 		case cmd_Quit:
 			return "Quit";
+		case cmd_RawOutputQuit:
+			return "RawOutputQuit";
 		case cmd_ShowMenu:
 			return "ShowMenu";
 		case cmd_FlushBookmarks:
@@ -233,6 +237,11 @@ cmd_string(int cmd)
 		case cmd_ShowCursor:
 			return "ShowCursor";
 
+		case cmd_BoldLabelsToggle:
+			return "BoldLabelsToggle";
+		case cmd_BoldCursorToggle:
+			return "BoldCursorToggle";
+
 		default:
 			return "unknown command";
 	}
@@ -246,6 +255,8 @@ translate_event(int c, bool alt)
 	{
 		switch (c)
 		{
+			case 'b':
+				return cmd_BoldLabelsToggle;
 			case 'c':
 				return cmd_ShowCursor;
 			case 'l':
@@ -262,6 +273,8 @@ translate_event(int c, bool alt)
 				return cmd_PrevBookmark;
 			case 'j':
 				return cmd_NextBookmark;
+			case 'q':
+				return cmd_RawOutputQuit;
 			case '9':
 				return cmd_ShowMenu;
 			case 27:
@@ -415,6 +428,9 @@ theme_get_cmd(int theme)
 			return cmd_SetTheme_SolarLight;
 		case 19:
 			return cmd_SetTheme_GruvboxLight;
+		case 20:
+			return cmd_SetTheme_TaoLight;
+
 	};
 
 	return cmd_Invalid;
@@ -469,6 +485,8 @@ cmd_get_theme(int cmd)
 			return 18;
 		case cmd_SetTheme_GruvboxLight:
 			return 19;
+		case cmd_SetTheme_TaoLight:
+			return 20;
 	};
 
 	return 1;
