@@ -11,6 +11,8 @@
  *-------------------------------------------------------------------------
  */
 
+#include <stdbool.h>
+
 #include "pspg.h"
 #include "st_menu.h"
 #include "commands.h"
@@ -27,6 +29,7 @@ ST_CMDBAR_ITEM _bottombar[] = {
 ST_MENU_ITEM _file[] = {
 	{"~S~ave", cmd_SaveData, "s"},
 	{"--"},
+	{"Raw output ~q~uit", cmd_RawOutputQuit, "M-q"},
 	{"E~x~it", cmd_Quit, "q, F10"},
 	{NULL}
 };
@@ -93,6 +96,7 @@ ST_MENU_ITEM _theme[] = {
 	{"_o_Solar Dark theme", cmd_SetTheme_SolarDark},
 	{"_g_Solar Light theme", cmd_SetTheme_SolarLight},
 	{"_u_Gruvbox Light theme", cmd_SetTheme_GruvboxLight},
+	{"_t_Tao Light theme", cmd_SetTheme_TaoLight},
 	{NULL},
 };
 
@@ -107,15 +111,16 @@ ST_MENU_ITEM _options[] = {
 	{"--"},
 	{"Show cursor", cmd_ShowCursor, "M-c"},
 	{"Show line ~n~umbers", cmd_RowNumToggle, "M-n"},
+	{"Show top bar", cmd_ShowTopBar, NULL},
+	{"Show bottom bar", cmd_ShowBottomBar, NULL},
 	{"--"},
 	{"~M~ouse support", cmd_MouseToggle, "M-m"},
 	{"~Q~uiet mode", cmd_SoundToggle, NULL},
 	{"--"},
-	{"Show top bar", cmd_ShowTopBar, NULL},
-	{"Show bottom bar", cmd_ShowBottomBar, NULL},
-	{"--"},
 	{"Force unicode ~b~orders", cmd_UtfArtToggle, NULL},
 	{"Force ~a~scii menu", cmd_MenuAsciiArtToggle, NULL},
+	{"Bold labels", cmd_BoldLabelsToggle, "M-b"},
+	{"Bold cursor", cmd_BoldCursorToggle, NULL},
 	{"~T~heme", MENU_ITEM_THEME, NULL, 0, 0,  0, _theme},
 	{"--"},
 	{"~S~ave setup", cmd_SaveSetup, NULL},
@@ -292,6 +297,9 @@ post_menu(Options *opts, struct ST_MENU *menu)
 	st_menu_set_option(menu, cmd_RowNumToggle, ST_MENU_OPTION_MARKED, opts->show_rownum);
 	st_menu_set_option(menu, cmd_ShowCursor, ST_MENU_OPTION_MARKED, !opts->no_cursor);
 
+	st_menu_set_option(menu, cmd_BoldLabelsToggle, ST_MENU_OPTION_MARKED, opts->bold_labels);
+	st_menu_set_option(menu, cmd_BoldCursorToggle, ST_MENU_OPTION_MARKED, opts->bold_cursor);
+
 	st_menu_reset_all_submenu_options(menu, MENU_ITEM_THEME, ST_MENU_OPTION_MARKED);
 	st_menu_enable_option(menu, theme_get_cmd(opts->theme), ST_MENU_OPTION_MARKED);
 }
