@@ -10,11 +10,26 @@
  *
  *-------------------------------------------------------------------------
  */
+#if defined HAVE_NCURSESW_CURSES_H
+#include <ncursesw/curses.h>
+#elif defined HAVE_NCURSESW_H
+#include <ncursesw.h>
+#elif defined HAVE_NCURSES_CURSES_H
+#include <ncurses/curses.h>
+#elif defined HAVE_NCURSES_H
+#include <ncurses.h>
+#elif defined HAVE_CURSES_H
 #include <curses.h>
+#else
+/* fallback */
+#include <ncurses/ncurses.h>
+#endif
+
 #include <ctype.h>
 #include <errno.h>
 #include <getopt.h>
 #include <math.h>
+#include <stdbool.h>
 #include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -22,13 +37,16 @@
 #include <langinfo.h>
 #include <libgen.h>
 #include <locale.h>
-#include <unistd.h>
-
 #include <signal.h>
-#include <sys/ioctl.h>
 
-#include <sys/param.h>
+#ifdef GWINSZ_IN_SYS_IOCTL
+# include <sys/ioctl.h>
+#else
+# include <termios.h>
+#endif
+
 #include <time.h>
+#include <unistd.h>
 
 #include "commands.h"
 #include "config.h"
@@ -67,7 +85,7 @@
 #endif
 #endif
 
-#define PSPG_VERSION "1.6.2"
+#define PSPG_VERSION "1.6.8"
 
 /* GNU Hurd does not define MAXPATHLEN */
 #ifndef MAXPATHLEN
@@ -728,12 +746,12 @@ strncpytrim(Options *opts, char *dest, const char *src,
 
 	while(nsrc > 0)
 	{
-		int	clen;
+		size_t	clen;
 
 		if (*src == '\0')
 			break;
 
-		clen = opts->force8bit ? 1 : utf8charlen(*src);
+		clen = (size_t) opts->force8bit ? 1 : utf8charlen(*src);
 		if (clen <= ndest && clen <= nsrc)
 		{
 			int		i;
@@ -1346,7 +1364,7 @@ print_status(Options *opts, ScrDesc *scrdesc, DataDesc *desc,
 		/* less-status-bar */
 		char	title[65];
 		char	*str;
-		int		bytes = sizeof(title) - 2;
+		size_t	bytes = sizeof(title) - 2;
 		char	*ptr = title;
 
 		if (desc->title_rows > 0 && desc->title[0] != '\0')
@@ -1521,7 +1539,7 @@ readline_redisplay()
 
 	if (!force8bit)
 	{
-		int prompt_dsplen = utf_string_dsplen(rl_display_prompt, SIZE_MAX);
+		size_t prompt_dsplen = utf_string_dsplen(rl_display_prompt, SIZE_MAX);
 
 		cursor_col = prompt_dsplen
 					  + readline_utf_string_dsplen(rl_line_buffer, rl_point, prompt_dsplen);
@@ -1721,7 +1739,7 @@ get_event(MEVENT *mevent, bool *alt)
 
 #endif
 
-#if NCURSES_WIDECHAR > 0
+#if NCURSES_WIDECHAR > 0 && defined HAVE_NCURSESW
 
 	wint_t	ch;
 	int		ret;
@@ -1812,7 +1830,7 @@ main(int argc, char *argv[])
 	int		event_keycode = 0;
 	int		prev_event_keycode = 0;
 	int		next_event_keycode = 0;
-	int		command;
+	int		command = cmd_Invalid;
 	long	last_ms = 0;							/* time of last mouse release in ms */
 	time_t	last_sec = 0;							/* time of last mouse release in sec */
 	int		next_command = cmd_Invalid;
@@ -1849,6 +1867,9 @@ main(int argc, char *argv[])
 	bool	prev_event_is_mouse_press = false;
 	int		prev_mouse_event_y = -1;
 	int		prev_mouse_event_x = -1;
+	bool	only_for_tables = false;
+
+	bool	raw_output_quit = false;
 
 	struct winsize size;
 
@@ -1872,6 +1893,9 @@ main(int argc, char *argv[])
 		{"line-numbers", no_argument, 0, 9},
 		{"quit-if-one-screen", no_argument, 0, 'F'},
 		{"version", no_argument, 0, 'V'},
+		{"bold-labels", no_argument, 0, 12},
+		{"bold-cursor", no_argument, 0, 13},
+		{"only-for-tables", no_argument, 0, 14},
 		{0, 0, 0, 0}
 	};
 
@@ -1900,6 +1924,8 @@ main(int argc, char *argv[])
 	opts.tabular_cursor = false;
 	opts.freezed_cols = -1;				/* default will be 1 if screen width will be enough */
 	opts.force_ascii_art = false;
+	opts.bold_labels = false;
+	opts.bold_cursor = false;
 
 	load_config(tilde("~/.pspgconf"), &opts);
 
@@ -1929,6 +1955,8 @@ main(int argc, char *argv[])
 				fprintf(stderr, "  -c N           fix N columns (0..9)\n");
 				fprintf(stderr, "  -f file        open file\n");
 				fprintf(stderr, "  -X             don't use alternate screen\n");
+				fprintf(stderr, "  --bold-labels  row, column labels use bold font\n");
+				fprintf(stderr, "  --bold-cursor  cursor use bold font\n");
 				fprintf(stderr, "  --help         show this help\n");
 				fprintf(stderr, "  --force-uniborder\n");
 				fprintf(stderr, "                 replace ascii borders by unicode borders\n");
@@ -1954,6 +1982,8 @@ main(int argc, char *argv[])
 				fprintf(stderr, "                 don't show bottom, top bar or both\n");
 				fprintf(stderr, "  --tabular-cursor\n");
 				fprintf(stderr, "                 cursor is visible only when data has table format\n");
+				fprintf(stderr, "  --only-for-tables\n");
+				fprintf(stderr, "                 use std pager when content is not table\n");
 				fprintf(stderr, "  -V, --version  show version\n\n");
 				fprintf(stderr, "pspg shares lot of key commands with less pager or vi editor.\n");
 				exit(0);
@@ -1998,6 +2028,16 @@ main(int argc, char *argv[])
 			case 11:
 				opts.tabular_cursor = true;
 				break;
+			case 12:
+				opts.bold_labels = true;
+				break;
+			case 13:
+				opts.bold_cursor = true;
+				break;
+			case 14:
+				only_for_tables = true;
+				break;
+
 			case 'V':
 				fprintf(stdout, "pspg-%s\n", PSPG_VERSION);
 
@@ -2097,6 +2137,58 @@ main(int argc, char *argv[])
 		fp = NULL;
 	}
 
+	if (desc.headline != NULL)
+		detected_format = translate_headline(&opts, &desc);
+
+	if (!detected_format && only_for_tables)
+	{
+		const char *pagerprog;
+		FILE	   *fout = NULL;
+		LineBuffer *lnb = &desc.rows;
+		int			lnb_row = 0;
+
+		pagerprog = getenv("PSPG_TEXT_PAGER");
+		if (!pagerprog)
+			pagerprog = getenv("PAGER");
+		if (!pagerprog)
+			pagerprog = "more";
+		else
+		{
+			/* if PAGER is empty or all-white-space, don't use pager */
+			if (strspn(pagerprog, " \t\r\n") == strlen(pagerprog))
+				fout = stdout;
+		}
+
+		if (!fout)
+		{
+			fout = popen(pagerprog, "w");
+			if (!fout)
+			{
+				/* if popen fails, silently proceed without pager */
+				fout = stdout;
+			}
+		}
+
+		if (fout != stdout)
+		{
+			signal(SIGPIPE, SIG_IGN);
+			signal(SIGINT, SIG_IGN);
+		}
+
+		while (lnb_row < lnb->nrows)
+		{
+			int r;
+			r = fprintf(fout, "%s\n", lnb->rows[lnb_row++]);
+			if (r < 0)
+				break;
+		}
+
+		if (fout != stdout)
+			pclose(fout);
+
+		return 0;
+	}
+
 	if (!isatty(fileno(stdin)))
 	{
 		if (freopen("/dev/tty", "r", stdin) != NULL)
@@ -2135,7 +2227,7 @@ main(int argc, char *argv[])
 
 reinit_theme:
 
-	initialize_color_pairs(opts.theme);
+	initialize_color_pairs(opts.theme, opts.bold_labels, opts.bold_cursor);
 
 	cbreak();
 	keypad(stdscr, TRUE);
@@ -2169,9 +2261,6 @@ reinit_theme:
 
 	}
 
-	if (desc.headline != NULL)
-		detected_format = translate_headline(&opts, &desc);
-
 	if (desc.headline_transl != NULL && !desc.is_expanded_mode)
 		desc.first_data_row = desc.border_head_row + 1;
 	else if (desc.title_rows > 0 && desc.is_expanded_mode)
@@ -2587,6 +2676,11 @@ hide_menu:
 			break;
 		else if (command == cmd_Invalid)
 			continue;
+		else if (command == cmd_RawOutputQuit)
+		{
+			raw_output_quit = true;
+			break;
+		}
 
 		switch (command)
 		{
@@ -2723,10 +2817,21 @@ reset_search:
 			case cmd_SetTheme_SolarDark:
 			case cmd_SetTheme_SolarLight:
 			case cmd_SetTheme_GruvboxLight:
+			case cmd_SetTheme_TaoLight:
 				opts.theme = cmd_get_theme(command);
 				reinit = true;
 				goto reinit_theme;
 
+			case cmd_BoldLabelsToggle:
+				opts.bold_labels = !opts.bold_labels;
+				reinit = true;
+				goto reinit_theme;
+
+			case cmd_BoldCursorToggle:
+				opts.bold_cursor = !opts.bold_cursor;
+				reinit = true;
+				goto reinit_theme;
+
 			case cmd_MouseToggle:
 				{
 					if (!opts.no_mouse)
@@ -3161,12 +3266,12 @@ recheck_left:
 
 							for (i = 1; i <= 30; i++)
 							{
-								int		pos = scrdesc.fix_cols_cols + cursor_col - i;
+								int		pos = scrdesc.fix_cols_cols + cursor_col - i - 1;
 
 								if (pos < 0)
 									break;
 
-								if (desc.headline_transl[i] == 'I')
+								if (desc.headline_transl[pos] == 'I')
 								{
 									move_left = i;
 									break;
@@ -4054,7 +4159,15 @@ refresh:
 
 	endwin();
 
-	if (no_alternate_screen)
+	if (raw_output_quit)
+	{
+		LineBuffer *lnb = &desc.rows;
+		int			lnb_row = 0;
+
+		while (lnb_row < lnb->nrows)
+			printf("%s\n", lnb->rows[lnb_row++]);
+	}
+	else if (no_alternate_screen)
 	{
 		draw_data(&opts, &scrdesc, &desc, first_data_row, first_row, cursor_col,
 				  footer_cursor_col, fix_rows_offset);
