@@ -1,5 +1,17 @@
+#if defined HAVE_NCURSESW_CURSES_H
+#include <ncursesw/curses.h>
+#elif defined HAVE_NCURSESW_H
+#include <ncursesw.h>
+#elif defined HAVE_NCURSES_CURSES_H
+#include <ncurses/curses.h>
+#elif defined HAVE_NCURSES_H
 #include <ncurses.h>
-#include <panel.h>
+#elif defined HAVE_CURSES_H
+#include <curses.h>
+#else
+/* fallback */
+#include <ncurses/ncurses.h>
+#endif
 
 #ifndef _ST_MENU_H
 
