@@ -14,7 +14,22 @@
 #ifndef PSPG_THEMES_H
 #define PSPG_THEMES_H
 
+#include <stdbool.h>
+
+#if defined HAVE_NCURSESW_CURSES_H
+#include <ncursesw/curses.h>
+#elif defined HAVE_NCURSESW_H
+#include <ncursesw.h>
+#elif defined HAVE_NCURSES_CURSES_H
+#include <ncurses/curses.h>
+#elif defined HAVE_NCURSES_H
+#include <ncurses.h>
+#elif defined HAVE_CURSES_H
 #include <curses.h>
+#else
+/* fallback */
+#include <ncurses/ncurses.h>
+#endif
 
 typedef struct
 {
@@ -48,7 +63,7 @@ typedef struct
 #define		WINDOW_ROWNUM			7
 #define		WINDOW_ROWNUM_LUC		8
 
-extern void initialize_color_pairs(int theme);
+extern void initialize_color_pairs(int theme, bool bold_labels, bool bold_cursor);
 extern void initialize_theme(int theme, int window_identifier, bool is_tabular_fmt, bool no_highlight_lines, Theme *t);
 
-#endif
\ No newline at end of file
+#endif
